@@ -32,7 +32,7 @@ const NIX_PACKS_VERSION: &str = env!("CARGO_PKG_VERSION");
 static NIXPKGS_ARCHIVE: &str = "30d3d79b7d3607d56546dd2a6b49e156ba0ec634";
 
 // Debian 11
-static BASE_IMAGE: &str = "debian:buster-slim";
+static BASE_IMAGE: &str = "debian:bullseye-slim";
 
 #[derive(Debug)]
 pub struct AppBuilderOptions {
@@ -43,6 +43,7 @@ pub struct AppBuilderOptions {
     pub out_dir: Option<String>,
     pub plan_path: Option<String>,
     pub tags: Vec<String>,
+    pub quiet: bool,
 }
 
 impl AppBuilderOptions {
@@ -55,6 +56,7 @@ impl AppBuilderOptions {
             out_dir: None,
             plan_path: None,
             tags: Vec::new(),
+            quiet: false,
         }
     }
 }
@@ -169,6 +171,10 @@ impl<'a> AppBuilder<'a> {
                 .arg("-t")
                 .arg(name.clone());
 
+            if self.options.quiet {
+                docker_build_cmd.arg("--quiet");
+            }
+
             // Add build environment variables
             for (name, value) in plan.variables.clone().unwrap_or_default().iter() {
                 docker_build_cmd
@@ -428,6 +434,12 @@ impl<'a> AppBuilder<'a> {
             .map(|cmd| format!("RUN {}", cmd))
             .unwrap_or_else(|| "".to_string());
 
+        let path_env = if let Some(paths) = install_phase.paths {
+            format!("ENV PATH {}:$PATH", paths.join(":"))
+        } else {
+            "".to_string()
+        };
+
         // Files to copy for install phase
         // If none specified, copy over the entire app
         let install_files = install_phase
@@ -500,6 +512,7 @@ impl<'a> AppBuilder<'a> {
           # Install
           {install_copy_cmd}
           {install_cmd}
+          {path_env}
 
           # Build
           {build_copy_cmd}
@@ -514,6 +527,7 @@ impl<'a> AppBuilder<'a> {
         args_string=args_string,
         install_copy_cmd=get_copy_command(&install_files, app_dir),
         install_cmd=install_cmd,
+        path_env=path_env,
         build_copy_cmd=get_copy_command(&build_files, app_dir),
         build_cmd=build_cmd,
         start_copy_cmd=get_copy_command(&start_files, app_dir),
